.. Magnum Release Notes documentation master file, created by
   sphinx-quickstart on Tue Mar 29 10:17:02 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Magnum Release Notes's documentation!
================================================

Contents:

.. toctree::
   :maxdepth: 2

   unreleased
   ussuri
   train
   stein
   rocky
   queens
   pike
   ocata
   newton
   mitaka
   liberty

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
